offsettools.update_offset_values_of_component
=============================================

.. autofunction:: abjad.tools.offsettools.update_offset_values_of_component.update_offset_values_of_component
   :noindex:
